#!/bin/python
# Vietoris-Rips complex visualization of wifi data
#
# Copyright (c) 2015, Michael Robinson
# Distribution of unaltered copies permitted for noncommercial use only
# All other uses require express permission of the author
# This software comes with no warrantees express or implied

import os
import numpy as np
import matplotlib.pyplot as plt
import simplicialHomology as sh

def plot_complex(locations,complex,color=None):
    """Plot a complex given locations of nodes"""
    colors='cbgr'
    for idx,f in enumerate(complex):
        if color != None:
            col=colors[color[idx]]
        else:
            col='g'
        if len(f)>2:
            for face in sh.ksublists(f,3):
                x,y=zip(*[locations[i] for i in face])
                plt.fill(x,y,col,alpha=0.5)
        elif len(f)>=2:
            x,y=zip(*[locations[i] for i in f])
            plt.fill(x,y,col,alpha=0.5)

    x,y=zip(*locations)
    plt.plot(x,y,'k.',ms=4*np.pi)
    for i in range(len(locations)):
        plt.text(x[i],y[i]+0.01,str(i))
    return

# Ingest data
pts=[]
with open('eight.csv','rt') as f1:
    f1.readline()
    for line in f1:
        pts.append(np.array(map(float,line.split(','))))

# Center point
ptsmat=np.array(pts).T

# Run PCA for visualization
u,s,v=np.linalg.svd(np.dot(ptsmat,ptsmat.T))
locations=np.dot(v[0:2,:],ptsmat).T

# Construct Vietoris Rips complex
# VARY THE DIAMETER PARAMETER; beware larger than 25 or so runs very slow
vr=sh.vietorisRips(pts,diameter=20)

plot_complex(locations,vr)
plt.show()
plt.savefig('vietoris_rips.png')
