#!/bin/python
# Visualize protein-protein interactions as a flag complex
#
# Copyright (c) 2015, Michael Robinson
# Distribution of unaltered copies permitted for noncommercial use only
# All other uses require express permission of the author
# This software comes with no warrantees express or implied

import pandas as pd
import networkx as nx
import numpy as np
import matplotlib.pyplot as plt
import simplicialHomology as sh

def plot_complex(locations,complex,color=None):
    """Plot a complex given locations of nodes"""
    colors='cbgr'
    for idx,f in enumerate(complex):
        if color != None:
            col=colors[color[idx]]
        else:
            col='g'
        if len(f)>2:
            for face in sh.ksublists(f,3):
                x,y=zip(*[locations[i] for i in face])
                plt.fill(x,y,col,alpha=0.5)
        elif len(f)>=2:
            x,y=zip(*[locations[i] for i in f])
            plt.fill(x,y,col,alpha=0.5)

    x=[]
    y=[]
    names=[]
    for k,v in locations.iteritems():
        x.append(v[0])
        y.append(v[1])
        names.append(k)
    plt.plot(x,y,'k.',ms=4*np.pi)
    for i in range(len(locations)):
        plt.text(x[i],y[i]+0.01,names[i])
    return

# Load the data
dfPP=pd.read_table('baylor_ppi.txt',sep='\t* *')

# Maximum number of stars to use
maxstars=500

G=nx.Graph()
# Iterate over some entities
starcount=0
for i,e1 in enumerate(dfPP['entity1']):
    if starcount > maxstars: break
    # Compute the star over this entity
    verts=dfPP['entity1'][dfPP['entity2'][:]==e1]
    verts.append(dfPP['entity2'][dfPP['entity1'][:]==e1])
   
    # Filter out edges that connect within the star
    subgraph=dfPP[['entity1','entity2']][dfPP['entity1'].isin(verts) & dfPP['entity2'].isin(verts)]
    if not subgraph.empty:
        G.add_edges_from(subgraph.values)
        starcount += 1

locations=nx.spring_layout(G)
complex=nx.find_cliques(G)

plot_complex(locations,complex)
plt.savefig('s1a6.png')
plt.show()
